==> haskell-path-0.9.6-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-path-z-os-string-compat
version:              0.9.6
package-name:         path
lib-name:             os-string-compat
id:                   path-0.9.6-1MItR0kUpDAAX8Q0JHydOd-os-string-compat
key:                  path-0.9.6-1MItR0kUpDAAX8Q0JHydOd-os-string-compat
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  de365f06dbaad1dc9ab177a6dcaa853b
exposed-modules:
    System.OsString.Compat.Posix System.OsString.Compat.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-1MItR0kUpDAAX8Q0JHydOd-os-string-compat
depends:              base-4.18.2.1 filepath-1.4.300.1
haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.6
visibility:           public
id:                   path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
key:                  path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  596c7fb6ea053e80118ae7f3c5f816f5
exposed:              True
exposed-modules:
    OsPath OsPath.Internal OsPath.Internal.Posix
    OsPath.Internal.Windows OsPath.Posix OsPath.Windows Path
    Path.Internal Path.Internal.Posix Path.Internal.Windows Path.Posix
    Path.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-7b6FXKI3CMdJjRU7VALKqo
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    path-0.9.6-1MItR0kUpDAAX8Q0JHydOd-os-string-compat
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.9.6-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-path-z-os-string-compat
version:              0.9.6
package-name:         path
lib-name:             os-string-compat
id:                   path-0.9.6-I8w13lVUr7T8w32WnkxrBm-os-string-compat
key:                  path-0.9.6-I8w13lVUr7T8w32WnkxrBm-os-string-compat
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  e18ce7d5cc9a60104ebc6dcfac590b9f
exposed-modules:
    System.OsString.Compat.Posix System.OsString.Compat.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-I8w13lVUr7T8w32WnkxrBm-os-string-compat
depends:              base-4.18.2.1 filepath-1.4.300.1
haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.6
visibility:           public
id:                   path-0.9.6-JZJSfxZgLNX9Y539GdP67P
key:                  path-0.9.6-JZJSfxZgLNX9Y539GdP67P
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  ec981676786a72f5d120c6ccc83813fa
exposed:              True
exposed-modules:
    OsPath OsPath.Internal OsPath.Internal.Posix
    OsPath.Internal.Windows OsPath.Posix OsPath.Windows Path
    Path.Internal Path.Internal.Posix Path.Internal.Windows Path.Posix
    Path.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-0.9.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.6-JZJSfxZgLNX9Y539GdP67P
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    path-0.9.6-I8w13lVUr7T8w32WnkxrBm-os-string-compat
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
